@@ -1234,7 +1234,7 @@ EFI_STATUS showVersion(struct Command *pCmd)
   }
 
   ReturnCode = pNvmDimmConfigProtocol->GetDimms(pNvmDimmConfigProtocol, DimmCount,
-    DIMM_INFO_CATEGORY_ALL, pDimms);
+    DIMM_INFO_CATEGORY_NONE, pDimms);
   if (EFI_ERROR(ReturnCode)) {
     ReturnCode = EFI_ABORTED;
     PRINTER_SET_MSG(pPrinterCtx, ReturnCode, CLI_ERR_INTERNAL_ERROR);
@@ -1276,6 +1276,7 @@ EFI_STATUS showVersion(struct Command *pCmd)
 Finish:
   PRINTER_PROCESS_SET_BUFFER(pPrinterCtx);
   FREE_POOL_SAFE(pPath);
+  FREE_POOL_SAFE(pDimms);
   NVDIMM_EXIT_I64(ReturnCode);
   return ReturnCode;
 }
